@@ -6,7 +6,7 @@ import json
 import httpx
 from typing import Any, Dict, List, Optional, Union
 from datetime import datetime
-from .types import Session, SessionStatus,SessionSchedule, SessionScheduleStatus, ScheduledMessageConfig, ScheduledNodeConfig
+from .types import Session, SessionStatus, SessionUpdateFields, SessionSchedule, SessionScheduleStatus, ScheduledMessageConfig, ScheduledNodeConfig
 from .messages import Messages
 from .survey_submissions import SurveySubmissions
 from .exceptions import create_error_from_response
@@ -141,14 +141,16 @@ class Sessions:
     async def update(
         self,
         session_id: str,
+        fields: Optional[SessionUpdateFields] = None,
         metadata: Optional[Dict[str, Any]] = None,
     ) -> Session:
         """
-        Update session metadata.
+        Update session fields.
         
         Args:
             session_id: ID of the session to update
-            metadata: New metadata to set
+            fields: Session fields to update (metadata, status, agent_id, etc.)
+            metadata: [DEPRECATED] New metadata to set - use fields instead
             
         Returns:
             Updated session object
@@ -159,9 +161,13 @@ class Sessions:
             ValidationError: If request validation fails
             APIError: For other API errors
         """
-        payload = {}
-        if metadata is not None:
-            payload["metadata"] = metadata
+        if fields is not None:
+            payload = {"fields": fields}
+        elif metadata is not None:
+            # Backward compatibility
+            payload = {"fields": {"metadata": metadata}}
+        else:
+            raise ValueError("Either 'fields' or 'metadata' must be provided")
         
         response = await self._client.patch(
             url=f"{self.api_url}/sessions/{session_id}",
@@ -282,6 +288,7 @@ class Sessions:
         self,
         contact_id: Optional[str] = None,
         status: Optional[SessionStatus] = None,
+        metadata: Optional[Dict[str, Union[str, int, float]]] = None,
         offset: Optional[int] = None,
         limit: Optional[int] = None,
     ) -> List[Session]:
@@ -291,6 +298,7 @@ class Sessions:
         Args:
             contact_id: Filter by contact ID
             status: Filter by session status
+            metadata: Filter by metadata fields (supports nested paths like "internal.user_id")
             offset: Number of results to skip (for pagination)
             limit: Maximum number of results to return
             
@@ -311,6 +319,8 @@ class Sessions:
             payload["offset"] = offset
         if limit is not None:
             payload["limit"] = limit
+        if metadata is not None:
+            payload["metadata"] = metadata
         
         response = await self._client.post(
             url=f"{self.api_url}/sessions/search",
