@@ -16,8 +16,10 @@ from .messages import (
     MessageContentFunctionResult,
     MessageContentThought,
     MessageRole,
+    MessageDeliveryStatus,
+    MESSAGE_ERROR_CODES,
 )
-from .agents import Agent, AIAgent, HumanAgent, AgentUpdateFields
+from .agents import Agent, AIAgent, HumanAgent, AgentUpdateFields, create_agent
 from .conversations import Conversation, ConversationUpdateFields
 from .tags import Tag, TagUpdateFields
 from .conversation_tags import ConversationTag
@@ -62,11 +64,13 @@ __all__ = [
     "MessageContentFunctionResult",
     "MessageContentThought",
     "MessageRole",
+    "MessageDeliveryStatus",
     # Agents
     "Agent",
     "HumanAgent",
     "AIAgent",
     "AgentUpdateFields",
+    "create_agent",
     # Tags
     "Tag",
     "TagUpdateFields",
@@ -85,4 +89,6 @@ __all__ = [
     "Config",
     "ConfigKeys",
     "ConversationsConfig",
+    # Error codes
+    "MESSAGE_ERROR_CODES",
 ]
